==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapAuthenticatorConfigEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setId((String) value);
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (String) e.getAlias();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setAlias((String) value);
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAuthenticatorConfigEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (String) e.getId();
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        public static final String FIELD_NAME_CAMEL_CASE = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (String) e.getAlias();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setAlias((String) value);
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        public static final String FIELD_NAME_CAMEL_CASE = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
    },
}
